import React from 'react';
import {Context} from '../context-provider';
import AppLogo from '../images/app-icons/pling-store.png';
import Collections from './Collections';
import '../styles/AppDialogs.css';

import Close from '@material-ui/icons/Close';

function AppDialogs(){

    const { appState, appDispatch } = React.useContext(Context);

    function onCloseDialogClick(){
        appDispatch({type:'HIDE_DIALOG'});
    }

    let appDialogDisplay, 
        dialogOverlayClass = "inactive",
        dialogBackgroundOverlayDisplay;

    if (appState.dialog.show === true){

        dialogOverlayClass = "active";
        
        if (appState.dialog.id === "loading") appDialogDisplay = <LoadingDialog/>
        else if (appState.dialog.id === "about") appDialogDisplay = <AboutDialog onCloseDialogClick={onCloseDialogClick}/>
        else if (appState.dialog.id === "collections") appDialogDisplay = <CollectionsDialog onCloseDialogClick={onCloseDialogClick}/>

        if (appState.dialog.id !== "loading") dialogBackgroundOverlayDisplay = <div id="dialog-overlay-background" onClick={onCloseDialogClick}></div>
    
    }

    return (
        <div id="dialog-overlay" className={dialogOverlayClass}>
            {dialogBackgroundOverlayDisplay}
            {appDialogDisplay}
        </div>
    )
}

function DialogHeader(props){
    return (
        <header>
            <div className="header-content">
                <h3>{props.title}</h3>
            </div>
            <div className="header-control">
                <button onClick={props.onCloseDialogClick}>
                    <i className="material-icons md-medium md-dark md-active">
                        <Close/>
                    </i>
                </button>
            </div>
        </header>
    )
}

function LoadingDialog(){

    const { appState } = React.useContext(Context);

    return (
        <article className="dialog fade-in" id="loading-dialog">
            <article className="content">
                <div className="inner-content">
                    <figure><img src={AppLogo}/></figure>
                    <h3>Welcome to {appState.packageJson.productName}</h3>
                    <p>Loading ...</p>
                </div>
            </article>
        </article>
    )
}

function AboutDialog(props){

    const { appState } = React.useContext(Context);
    const packageJson = appState.packageJson;

    return (
        <article className="dialog fade-in" id="about-dialog">
            <DialogHeader 
                title={"About This App"}
                onCloseDialogClick={props.onCloseDialogClick}
            />
            <article className="content">
                <div className="inner-content">
                    <figure>
                        <img src={AppLogo}/>
                    </figure>
                    <h4>{packageJson.productName}</h4>
                    <p>{packageJson.version}</p>
                    <p>{packageJson.description}</p>
                    <p>
                        Author: {packageJson.author}<br/>
                        License: {packageJson.license}
                    </p>
                    <p>
                        Website: <a href={packageJson.repoHomepage}>{packageJson.repoHomepage}</a><br/>
                        Project page: <a href={packageJson.repository}>{packageJson.repository}</a><br/>
                        Report a bug: <a href={packageJson.repository}>{packageJson.bugs}</a>
                    </p>
                </div>
            </article>
        </article>
    )
}

function CollectionsDialog(props){
    return (
        <article id="collections-dialog" className="dialog fade-in">
            <DialogHeader 
                title={"My Collections"}
                onCloseDialogClick={props.onCloseDialogClick}
            />
            <article className="content">
                <Collections/>
            </article>
        </article>
    )
}

export default AppDialogs;